auth

package
v0.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 10, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type TokenStore

type TokenStore struct {
	// contains filtered or unexported fields
}

TokenStore persists OAuth tokens to disk, keyed by server URL.

func NewTokenStore

func NewTokenStore(baseDir string) *TokenStore

NewTokenStore creates a token store rooted at the given directory.

func (*TokenStore) Load

func (s *TokenStore) Load(serverURL string) (*oauth2.Token, error)

Load reads a cached token for the given server URL. Returns nil, nil if no token is cached or the file is corrupt.

func (*TokenStore) Save

func (s *TokenStore) Save(serverURL string, tok *oauth2.Token) error

Save writes a token to disk for the given server URL.

Jump to